@@ -182,8 +182,8 @@ class TAPShape:
 
     shapeID: str = ""
     shapeLabel: str = ""
-    start: bool = False
     sc_list: List[TAPStatementConstraint] = field(default_factory=list)
+#    statement_constraints: List[TAPStatementConstraint] = field(default_factory=list)
     sh_warnings: dict = field(default_factory=dict)
 
     def validate(self, config_dict=None):
